@@ -53,6 +53,7 @@ class TestProviderDataModels(base.TestCase):
             l7policy_id=self.l7policy_id,
             l7rule_id=self.l7rule_id,
             type='COOKIE',
+            project_id=self.project_id,
             value='chocolate')
 
         self.ref_l7policy = data_models.L7Policy(
@@ -66,6 +67,7 @@ class TestProviderDataModels(base.TestCase):
             redirect_pool_id=self.pool_id,
             redirect_url='/test',
             rules=[self.ref_l7rule],
+            project_id=self.project_id,
             redirect_prefix='http://example.com',
             redirect_http_code=301)
 
@@ -82,6 +84,7 @@ class TestProviderDataModels(base.TestCase):
             listener_id=self.listener_id,
             loadbalancer_id=self.loadbalancer_id,
             name='super_listener',
+            project_id=self.project_id,
             protocol='avian',
             protocol_port=42,
             sni_container_data=['sni_cert_data_1', 'sni_cert_data_2'],
@@ -95,7 +98,8 @@ class TestProviderDataModels(base.TestCase):
             client_ca_tls_container_data=None,
             client_ca_tls_container_ref=None,
             client_crl_container_data=None,
-            client_crl_container_ref=None)
+            client_crl_container_ref=None,
+            allowed_cidrs=None)
 
         self.ref_lb = data_models.LoadBalancer(
             admin_state_up=False,
@@ -126,6 +130,7 @@ class TestProviderDataModels(base.TestCase):
             monitor_port=8888,
             name='member',
             pool_id=self.pool_id,
+            project_id=self.project_id,
             protocol_port=80,
             subnet_id=self.mem_subnet_id,
             weight=1,
@@ -141,6 +146,7 @@ class TestProviderDataModels(base.TestCase):
             max_retries_down=3,
             name='member',
             pool_id=self.pool_id,
+            project_id=self.project_id,
             timeout=4,
             type='HTTP',
             url_path='/test',
@@ -156,6 +162,7 @@ class TestProviderDataModels(base.TestCase):
             members=[self.ref_member],
             name='pool',
             pool_id=self.pool_id,
+            project_id=self.project_id,
             listener_id=self.listener_id,
             protocol='avian',
             session_persistence=self.session_persistence)
@@ -167,6 +174,7 @@ class TestProviderDataModels(base.TestCase):
                                 'l7policy_id': self.l7policy_id,
                                 'l7rule_id': self.l7rule_id,
                                 'type': 'COOKIE',
+                                'project_id': self.project_id,
                                 'value': 'chocolate'}
 
         self.ref_l7policy_dict = {'action': 'REJECT',
@@ -176,6 +184,7 @@ class TestProviderDataModels(base.TestCase):
                                   'listener_id': self.listener_id,
                                   'name': 'l7policy',
                                   'position': 1,
+                                  'project_id': self.project_id,
                                   'redirect_pool_id': self.pool_id,
                                   'redirect_url': '/test',
                                   'rules': [self.ref_l7rule_dict],
@@ -207,6 +216,7 @@ class TestProviderDataModels(base.TestCase):
             'l7policies': [self.ref_l7policy_dict],
             'loadbalancer_id': self.loadbalancer_id,
             'name': 'super_listener',
+            'project_id': self.project_id,
             'protocol': 'avian',
             'protocol_port': 42,
             'sni_container_data': ['sni_cert_data_1', 'sni_cert_data_2'],
@@ -220,7 +230,8 @@ class TestProviderDataModels(base.TestCase):
             'client_ca_tls_container_data': None,
             'client_ca_tls_container_ref': None,
             'client_crl_container_data': None,
-            'client_crl_container_ref': None, }
+            'client_crl_container_ref': None,
+            'allowed_cidrs': None, }
 
         self.ref_lb_dict_with_listener = {
             'admin_state_up': False,
@@ -251,6 +262,7 @@ class TestProviderDataModels(base.TestCase):
             'monitor_port': 8888,
             'name': 'member',
             'pool_id': self.pool_id,
+            'project_id': self.project_id,
             'protocol_port': 80,
             'subnet_id': self.mem_subnet_id,
             'weight': 1,
@@ -266,6 +278,7 @@ class TestProviderDataModels(base.TestCase):
             'max_retries_down': 3,
             'name': 'member',
             'pool_id': self.pool_id,
+            'project_id': self.project_id,
             'timeout': 4,
             'type': 'HTTP',
             'url_path': '/test',
@@ -281,6 +294,7 @@ class TestProviderDataModels(base.TestCase):
             'members': [self.ref_member_dict],
             'name': 'pool',
             'pool_id': self.pool_id,
+            'project_id': self.project_id,
             'listener_id': self.listener_id,
             'protocol': 'avian',
             'session_persistence': self.session_persistence}
@@ -362,6 +376,7 @@ class TestProviderDataModels(base.TestCase):
         new_ref_lib_dict = deepcopy(self.ref_lb_dict)
         new_ref_lib_dict['pools'] = None
         new_ref_lib_dict['listeners'] = None
+        new_ref_lib_dict['additional_vips'] = None
 
         self.assertEqual(new_ref_lib_dict, ref_lb_converted_to_dict)
 
@@ -409,6 +424,7 @@ class TestProviderDataModels(base.TestCase):
         ref_lb_dict_with_listener = deepcopy(self.ref_lb_dict_with_listener)
         ref_lb_dict_with_listener['pools'] = None
         ref_lb_dict_with_listener['name'] = None
+        ref_lb_dict_with_listener['additional_vips'] = None
 
         ref_lb_converted_to_dict = ref_lb.to_dict(recurse=True,
                                                   render_unsets=True)
